import sys
import click

from ttsi.app import app, db


@click.group()
@click.version_option("1.0.0")
def main():
    """A TTSI CLI"""
    print("Welcome to ttsi CLI")
    pass


@main.command()
@click.argument('run', required=False)
def run(**kwargs):
    """Run application
    """
    app.run()

    pass


@main.command()
@click.argument('run', required=False)
def init(**kwargs):
    """Run application
    """
    db.create_all()

    pass


if __name__ == '__main__':
    args = sys.argv
    main()



from flask import Flask
from flask_sqlalchemy import SQLAlchemy
from flask_admin import Admin
from flask_admin.contrib.sqla import ModelView
import os
import secrets

app = Flask(__name__)
app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:////tmp/ttsi.db'
secret_key = os.environ.get('SECRET_KEY')

if not secret_key:
    tmp_file = "/tmp/ttsi_secret.txt"
    try:
        secret_key = open("/tmp/ttsi_secret.txt", "r").read()
    except FileNotFoundError:
        secret_key = secrets.token_urlsafe(16)
        f = open(tmp_file, "w")
        f.write(secret_key)
        f.close()

app.config['SECRET_KEY'] = s

db = SQLAlchemy(app)


@app.route("/")
def index():
    return "Hello World!"


class User(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    username = db.Column(db.String(80), unique=True, nullable=False)
    email = db.Column(db.String(120), unique=True, nullable=False)

    def __repr__(self):
        return '<User %r>' % self.username


admin = Admin(app)
admin.add_view(ModelView(User, db.session))



from setuptools import setup, find_packages

with open('README.rst') as f:
    readme = f.read()

setup(
    name='ttsi',
    version='0.0.6',
    description='Send reports by email',
    long_description=readme,
    author='Dacker',
    author_email='hello@dacker.co',
    url='https://github.com/dacker-team/ttsi',
    keywords='easily send reports email bi data',
    packages=find_packages(exclude=('tests', 'docs')),
    python_requires='>=3',
    entry_points={
        'console_scripts': ['ttsi=ttsi.__main__:main'],
    },
    install_requires=[
        "rq==1.9.0",
        "Flask==2.0.1",
        "pydatasource==0.2.46",
        "gunicorn==19.7.1",
        "flask-sqlalchemy==2.5.1",
        "flask-admin==1.5.8"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
